@@ -1,6 +1,8 @@
 package cmd
 
 import (
+	"time"
+
 	"github.com/go-acme/lego/v4/lego"
 	"github.com/urfave/cli/v2"
 	"software.sslmate.com/src/go-pkcs12"
@@ -142,3 +144,11 @@ func CreateFlags(defaultPath string) []cli.Flag {
 		},
 	}
 }
+
+func getTime(ctx *cli.Context, name string) time.Time {
+	value := ctx.Timestamp(name)
+	if value == nil {
+		return time.Time{}
+	}
+	return *value
+}
